@@ -3,8 +3,8 @@ from django.core.management.base import BaseCommand
 
 SHOP_DESCRIPTION = """
 <h1 class="first-heading">Welcome to LFS!</h1>
-<p>LFS is an online shop based on <a href="http://www.python.org/" target="_blank">Python</a>, 
-<a href="http://www.djangoproject.com/" target="_blank">Django</a> and 
+<p>LFS is an online shop based on <a href="http://www.python.org/" target="_blank">Python</a>,
+<a href="http://www.djangoproject.com/" target="_blank">Django</a> and
 <a href="http://jquery.com/" target="_blank">jQuery</a>.</p>
 
 <h1>Login</h1>
@@ -23,6 +23,7 @@ SHOP_DESCRIPTION = """
 </ul>
 """
 
+
 class Command(BaseCommand):
     args = ''
     help = 'Initializes LFS'
@@ -30,6 +31,7 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         from lfs.core.models import ActionGroup
         from lfs.core.models import Action
+        from lfs.core.models import Application
         from lfs.core.models import Country
         from lfs.core.models import Shop
 
@@ -50,7 +52,8 @@ class Command(BaseCommand):
         # Shop
         shop = Shop.objects.create(name="LFS", shop_owner="John Doe",
             from_email="john@doe.com", notification_emails="john@doe.com", description=SHOP_DESCRIPTION, default_country=usa)
-        shop.countries.add(usa)
+        shop.invoice_countries.add(usa)
+        shop.shipping_countries.add(usa)
 
         # Actions
         tabs = ActionGroup.objects.create(name="Tabs")
@@ -83,4 +86,8 @@ class Command(BaseCommand):
 
         # Pages
         Page.objects.create(title="Terms and Conditions", slug="terms-and-conditions", active=1, body="Enter your terms and conditions here.")
-        Page.objects.create(title="Imprint", slug="imprint", active=1, body="Enter your imprint here.")
\ No newline at end of file
+        Page.objects.create(title="Imprint", slug="imprint", active=1, body="Enter your imprint here.")
+
+        # Application object
+        Application.objects.create(version="0.6")
+
